<template>
  <div class="app-container">
    <el-card class="box-card">
      <el-row type="flex" align="middle" justify="space-between">
        <el-col :span="2">
          <div class="icon-container">
            <i class="el-icon-wind-power"></i>
          </div>
        </el-col>
        <el-col :span="2">
          <div>
            <div class="dashboard-item">
              <h3 style="color: #5C9BF8">{{ totalKiosks }}</h3>
              <p>卡口总数</p>
            </div>
          </div>
        </el-col>
        <el-col :span="2">
          <div class="dashboard-item">
            <h3>{{ uniqueKiosks }}</h3>
            <p>不唯一卡口数</p>
          </div>
        </el-col>
        <el-col :span="1">
          <div class="dashboard-item">
            <div style="width: 1px;height: 55px;border: 1px solid #D7EBFA;margin: 20px;"></div>
          </div>
        </el-col>
        <el-col :span="2">
          <div class="icon-container">
            <i class="el-icon-truck"></i>
          </div>
        </el-col>
        <el-col :span="2">
          <div class="dashboard-item">
            <h3 style="color: #5C9BF8">{{ totalCarData }}</h3>
            <p>过车数据总量</p>
          </div>
        </el-col>
        <el-col :span="2">
          <div class="dashboard-item">
            <h3>{{ uniqueCarData }}</h3>
            <p>不唯一数据量</p>
          </div>
        </el-col>
        <el-col :span="8"></el-col>
      </el-row>
    </el-card>

    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="卡口编号" prop="bayonetNumber">
        <el-input v-model="queryParams.bayonetNumber" placeholder="请输入卡口编号" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="卡口名称" prop="bayonetName">
        <el-input v-model="queryParams.bayonetName" placeholder="请输入卡口名称" clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="small" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="small" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
          v-hasPermi="['platform:platform:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['platform:platform:edit']">修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['platform:platform:remove']">删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
          v-hasPermi="['platform:platform:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="platformList" @selection-change="handleSelectionChange">
      <template v-for="(item, index) in tableHead">
        <el-table-column :key="item.name" :prop="item.prop" :label="item.label">
        </el-table-column>
      </template>

      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['platform:platform:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['platform:platform:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加或修改卡口过车数据一致性对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="卡口名称" prop="bayonetName">
          <el-input v-model="form.bayonetName" placeholder="请输入卡口名称" />
        </el-form-item>
        <el-form-item label="卡口编号" prop="bayonetNumber">
          <el-input v-model="form.bayonetNumber" placeholder="请输入卡口编号" />
        </el-form-item>
        <el-form-item label="过车数据量" prop="vehicleDataNumber">
          <el-input v-model="form.vehicleDataNumber" placeholder="请输入过车数据量" />
        </el-form-item>
        <el-form-item label="不唯一数据 " prop="notUniqueData">
          <el-input v-model="form.notUniqueData" placeholder="请输入不唯一数据 " />
        </el-form-item>
        <el-form-item label="不唯一数据量" prop="notUniqueDataNumber">
          <el-input v-model="form.notUniqueDataNumber" placeholder="请输入不唯一数据量" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="cancel">取 消</el-button>
        <el-button type="primary" @click="submitForm">确 定</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listPlatform, getPlatform, delPlatform, addPlatform, updatePlatform } from "@/api/platform/vehicle-data-monitor";
import { videoData, carData, faceData, equipment } from "./list";
import store from '@/store';

export default {
  name: "Platform",
  data() {
    return {
      totalKiosks: 1157,
      uniqueKiosks: 580,
      totalCarData: 1477422,
      uniqueCarData: 431163,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 卡口过车数据一致性表格数据
      platformList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        regionCode: null,
        bayonetName: null,
        bayonetNumber: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        bayonetName: [
          { required: true, message: "卡口名称不能为空", trigger: "blur" }
        ],
        bayonetNumber: [
          { required: true, message: "卡口编号不能为空", trigger: "blur" }
        ],
      },
      tableHead: []
    };
  },
  beforeRouteEnter(to, from, next) {
    console.log(to);
    next();
  },
  created() {
    if (this.$route.query.type === '1') this.tableHead = videoData[this.$route.query.index].columns;
    if (this.$route.query.type === '2') this.tableHead = carData[this.$route.query.index].columns;
    if (this.$route.query.type === '3') this.tableHead = faceData[this.$route.query.index].columns;
    if (this.$route.query.type === '4') this.tableHead = equipment[this.$route.query.index].columns;
    this.getList();
  },
  methods: {
    /** 查询卡口过车数据一致性列表 */
    getList() {
      this.loading = true;
      listPlatform(this.queryParams).then(response => {
        this.platformList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        regionCode: null,
        bayonetName: null,
        bayonetNumber: null,
        vehicleDataNumber: null,
        notUniqueData: null,
        notUniqueDataNumber: null,
        createTime: null,
        updateTime: null,
        deleted: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加卡口过车数据一致性";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids;
      getPlatform(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改卡口过车数据一致性";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updatePlatform(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addPlatform(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除卡口过车数据一致性编号为"' + ids + '"的数据项？').then(function () {
        return delPlatform(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => { });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('platform/platform/export', {
        ...this.queryParams
      }, `platform_${new Date().getTime()}.xlsx`);
    }
  }
};
</script>
<style scoped>
.box-card {
  background-color: #F5F9FE;
  width: 100%;
  margin-bottom: 20px;
  height: 120px
}

.icon-container {
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 20px;
  width: 20%;
  height: 80px;
  margin-left: 5%;
  background-color: #1890FF;
  font-size: 50px;
  color: #FFF;
  width: 85px;
}

.el-icon-refresh-left {
  font-size: 50px;
  color: #FFFFFF;
}

.dashboard-item {
  text-align: center;
}
</style>
